@@ -17,14 +17,14 @@
 
 """ Version and other info for this program
 """
-import os, sys
+import sys
 
 # We bypass the argparse mechanism in main.py because this import is executed before main.main()
 DEBUGGING = ('-d' in sys.argv or '--debug' in sys.argv)
-TESTING = False # add some test menu options
+TESTING = True # add some test menu options
 PROFILING = False# and DEBUGGING
 
-VERSION = '0.4.0'
+VERSION = '0.4.4'
 REPO_NAME = "argos"
 SCRIPT_NAME = "argos"
 PACKAGE_NAME = "argos"
@@ -44,22 +44,5 @@ EXIT_CODE_RESTART = 66 # Indicates the program is being 'restarted'
 KEY_PROGRAM = '_program'
 KEY_VERSION = '_version'
 
-# TODO: move to utils locations
-def program_directory():
-    """ Returns the program directory where this program is installed
-    """
-    return os.path.abspath(os.path.dirname(__file__))
 
 
-def resource_directory():
-    """ Returns directory with resources (images, style sheets, etc)
-    """
-    return os.path.join(program_directory(), 'img/')
-
-
-
-def icons_directory():
-    """ Returns the icons directory
-    """
-    return os.path.join(program_directory(), 'img/snipicons')
-
