@@ -18,11 +18,12 @@
 """ Base class for inspectors
 """
 import logging
+
 from argos.config.abstractcti import ResetMode
 from argos.config.groupcti import MainGroupCti
 from argos.info import DEBUGGING
 from argos.qt import QtWidgets, QtSignal
-from argos.utils.cls import type_name, check_class
+from argos.utils.cls import typeName, checkType
 from argos.widgets.constants import DOCK_SPACING, DOCK_MARGIN
 from argos.widgets.display import MessageDisplay
 from argos.widgets.misc import BasePanel
@@ -76,6 +77,7 @@ class AbstractInspector(QtWidgets.QStackedWidget):
     CONTENTS_PAGE_IDX = 1
 
     sigShowMessage = QtSignal(str)
+    sigUpdated = QtSignal(bool)  # Parameter indicates sucess
 
     def __init__(self, collector, parent=None):
         """ Constructor.
@@ -179,7 +181,7 @@ class AbstractInspector(QtWidgets.QStackedWidget):
             (the inspector is the configuration's target, hence the name).
 
             The reason parameter is a string (one of the UpdateReason values) that indicates why
-            the inspector contents whas updated. This can, for instance, be used to optimize
+            the inspector contents was updated. This can, for instance, be used to optimize
             drawing the inspector contents. Note that the reason may be undefined (None).
 
             The initiator may contain the object that initiated the updated. The type depends on the
@@ -211,20 +213,28 @@ class AbstractInspector(QtWidgets.QStackedWidget):
             self.config.refreshFromTarget()
             logger.debug("refreshFromTarget finished successfully")
 
+            self.sigUpdated.emit(True)
+
         except InvalidDataError as ex:
-            logger.info("Unable to draw the inspector contents: '{}'".format(ex))
             if str(ex):
-                # Exception message can be empty in common cases. Don't clear message label then.
+                # Exception message can be empty in common cases. Don't show the message label then.
+                logger.debug("Unable to draw the inspector contents: '{}'".format(ex))
                 self.sigShowMessage.emit(str(ex))
 
+            self.sigUpdated.emit(True)
+
         except Exception as ex:####
             if DEBUGGING:
                 raise
+
             logger.error("Error while drawing the inspector: {} ----".format(ex))
             logger.exception(ex)
             self._clearContents()
             self.setCurrentIndex(self.ERROR_PAGE_IDX)
-            self._showError(msg=str(ex), title=type_name(ex))
+            self._showError(msg=str(ex), title=typeName(ex))
+
+            self.sigUpdated.emit(False)
+
         else:
             logger.debug("---- updateContents finished successfully")
 
