@@ -41,8 +41,8 @@ from argos.inspector.pgplugins.pgctis import (
 from argos.inspector.pgplugins.pgplotitem import ArgosPgPlotItem
 from argos.qt import Qt, QtCore, QtGui, QtSlot
 
-from argos.utils.cls import array_has_real_numbers, check_class, is_an_array, to_string
-from argos.utils.cls import array_kind_label
+from argos.utils.cls import arrayHasRealNumbers, checkType, isAnArray, toString
+from argos.utils.cls import arrayKindLabel
 from argos.utils.defs import RIGHT_ARROW
 from argos.utils.masks import (ArrayWithMask, replaceMaskedValueWithFloat,
                                nanPercentileOfSubsampledArrayWithMask)
@@ -71,7 +71,7 @@ def calcPgImagePlot2dDataRange(pgImagePlot2d, percentage, crossPlot, subsample):
         :param bool subsample: if True, the image will be subsampled (to 200 by 200) before
             calculating the range. This to improve performance by large images.
     """
-    check_class(pgImagePlot2d.slicedArray, ArrayWithMask) # sanity check
+    checkType(pgImagePlot2d.slicedArray, ArrayWithMask) # sanity check
 
     if crossPlot is None:
         array = pgImagePlot2d.slicedArray  # the whole image
@@ -138,7 +138,7 @@ class PgImagePlot2dCti(MainGroupCti):
             Vice versa, it can connect signals to the target.
         """
         super(PgImagePlot2dCti, self).__init__(nodeName)
-        check_class(pgImagePlot2d, PgImagePlot2d)
+        checkType(pgImagePlot2d, PgImagePlot2d)
         self.pgImagePlot2d = pgImagePlot2d
         imagePlotItem = self.pgImagePlot2d.imagePlotItem
         viewBox = imagePlotItem.getViewBox()
@@ -487,10 +487,10 @@ class PgImagePlot2d(AbstractInspector):
         if slicedArray is None:
             self._clearContents()
             raise InvalidDataError()  # Don't show message, to common.
-        elif not array_has_real_numbers(slicedArray.data):
+        elif not arrayHasRealNumbers(slicedArray.data):
             self._clearContents()
             raise InvalidDataError(
-                "Selected item contains {} data.".format(array_kind_label(slicedArray.data)))
+                "Selected item contains {} data.".format(arrayKindLabel(slicedArray.data)))
         else:
             self.slicedArray = slicedArray
 
@@ -563,7 +563,7 @@ class PgImagePlot2d(AbstractInspector):
             Draws a vertical line and a symbol at the position of the probe.
         """
         try:
-            check_class(viewPos, QtCore.QPointF)
+            checkType(viewPos, QtCore.QPointF)
             show_data_point = False # shows the data point as a circle in the cross hair plots
             self.crossPlotRow, self.crossPlotCol = None, None
 
@@ -589,9 +589,9 @@ class PgImagePlot2d(AbstractInspector):
 
                     self.crossPlotRow, self.crossPlotCol = row, col
                     index = tuple([row, col])
-                    valueStr = to_string(self.slicedArray.data[index],
-                                         masked=self.slicedArray.maskAt(index),
-                                         maskFormat='&lt;masked&gt;')
+                    valueStr = toString(self.slicedArray.data[index],
+                                        masked=self.slicedArray.maskAt(index),
+                                        maskFormat='&lt;masked&gt;')
 
                     if self.config.probeCti.configValue:
                         txt = "({}, {}) = ({:d}, {:d}) {} {} = {}".format(
@@ -610,7 +610,7 @@ class PgImagePlot2d(AbstractInspector):
                         # First determine which points are connected or separated by masks/nans.
                         rowData = self.slicedArray.data[row, :]
                         connected = np.isfinite(rowData)
-                        if is_an_array(self.slicedArray.mask):
+                        if isAnArray(self.slicedArray.mask):
                             connected = np.logical_and(connected, ~self.slicedArray.mask[row, :])
                         else:
                             connected = (np.zeros_like(rowData)
@@ -664,7 +664,7 @@ class PgImagePlot2d(AbstractInspector):
                         # First determine which points are connected or separated by masks/nans.
                         colData = self.slicedArray.data[:, col]
                         connected = np.isfinite(colData)
-                        if is_an_array(self.slicedArray.mask):
+                        if isAnArray(self.slicedArray.mask):
                             connected = np.logical_and(connected, ~self.slicedArray.mask[:, col])
                         else:
                             connected = (np.zeros_like(colData)
