@@ -20,6 +20,8 @@
 from __future__ import division, print_function
 
 import logging
+import warnings
+
 import numpy as np
 import pyqtgraph as pg
 
@@ -44,7 +46,7 @@ from argos.inspector.pgplugins.pghistlutitem import HistogramLUTItem
 from argos.qt import QtCore, QtGui, QtWidgets, QtSlot
 from argos.qt.misc import setWidgetSizePolicy
 from argos.repo.colors import CmLibModelSingleton, DEFAULT_COLOR_MAP
-from argos.utils.cls import check_class
+from argos.utils.cls import checkType
 from argos.utils.masks import nanPercentileOfSubsampledArrayWithMask
 
 
@@ -279,14 +281,17 @@ class AbstractRangeCti(GroupCti):
         # So, while the range is the same size we need more decimals because we are not zoomed in
         # around zero.
         rangeMin, rangeMax = self.getTargetRange() # [[xmin, xmax], [ymin, ymax]]
-        maxOrder = np.log10(np.abs(max(rangeMax, rangeMin)))
-        diffOrder = np.log10(np.abs(rangeMax - rangeMin))
+        with warnings.catch_warnings():
+            # Ignore divide by zero warnings when all elements have the same value
+            warnings.simplefilter("ignore")
+            maxOrder = np.log10(np.abs(max(rangeMax, rangeMin)))
+            diffOrder = np.log10(np.abs(rangeMax - rangeMin))
 
-        extraDigits = 2 # add some extra digits to make each pan/zoom action show a new value.
-        precisionF = np.clip(abs(maxOrder - diffOrder) + extraDigits, extraDigits + 1, 25)
-        precision = int(precisionF) if np.isfinite(precisionF) else extraDigits + 1
-        #logger.debug("maxOrder: {}, diffOrder: {}, precision: {}"
-        #             .format(maxOrder, diffOrder, precision))
+            extraDigits = 2 # add some extra digits to make each pan/zoom action show a new value.
+            precisionF = np.clip(abs(maxOrder - diffOrder) + extraDigits, extraDigits + 1, 25)
+            precision = int(precisionF) if np.isfinite(precisionF) else extraDigits + 1
+            #logger.debug("maxOrder: {}, diffOrder: {}, precision: {}"
+            #             .format(maxOrder, diffOrder, precision))
 
         self.rangeMinCti.precision = precision
         self.rangeMaxCti.precision = precision
@@ -302,7 +307,7 @@ class AbstractRangeCti(GroupCti):
             Does nothing when self.getRefreshBlocked() returns True.
         """
         if self.getRefreshBlocked():
-            logger.debug("refreshMinMax blocked for {}".format(self.nodeName))
+            #logger.debug("refreshMinMax blocked for {}".format(self.nodeName))
             return
 
         self._forceRefreshMinMax()
@@ -420,7 +425,7 @@ class PgAxisRangeCti(AbstractRangeCti):
 
         super(PgAxisRangeCti, self).__init__(autoRangeFunctions=autoRangeFunctions,
                                              nodeName=nodeName, expanded=expanded)
-        check_class(viewBox, pg.ViewBox)
+        checkType(viewBox, pg.ViewBox)
         assert axisNumber in (X_AXIS, Y_AXIS), "axisNumber must be 0 or 1"
 
         self.viewBox = viewBox
@@ -487,7 +492,7 @@ class PgHistLutColorRangeCti(AbstractRangeCti):
         """
         super(PgHistLutColorRangeCti, self).__init__(autoRangeFunctions=autoRangeFunctions,
                                                      nodeName=nodeName, expanded=expanded)
-        check_class(histLutItem, HistogramLUTItem)
+        checkType(histLutItem, HistogramLUTItem)
         self.histLutItem = histLutItem
 
         # Connect signals
@@ -533,7 +538,7 @@ class PgColorLegendCti(AbstractRangeCti):
             autoRangeFunctions=autoRangeFunctions, nodeName=nodeName,
             expanded=True, paddingDefault=0)
 
-        check_class(legend, ColorLegendItem)
+        checkType(legend, ColorLegendItem)
         self.legend = legend
 
         self.paddingCti.defaultData = 0
@@ -578,7 +583,7 @@ class PgColorLegendLabelCti(ChoiceCti):
         super(PgColorLegendLabelCti, self).__init__(
             nodeName, editable=True, defaultData=defaultData, configValues=configValues)
 
-        check_class(colorLegendItem, ColorLegendItem)
+        checkType(colorLegendItem, ColorLegendItem)
         self.colorLegendItem = colorLegendItem
         self.collector = collector
 
@@ -605,7 +610,7 @@ class PgShowHistCti(BoolCti):
         """
         super(PgShowHistCti, self).__init__(nodeName, defaultData=defaultData)
 
-        check_class(colorLegendItem, ColorLegendItem)
+        checkType(colorLegendItem, ColorLegendItem)
         self.colorLegendItem = colorLegendItem
 
 
@@ -629,7 +634,7 @@ class PgShowDragLinesCti(BoolCti):
         self.marginCti = self.insertChild(
             IntCti("margins", 40, minValue=0, maxValue=250, stepSize=5))
 
-        check_class(colorLegendItem, ColorLegendItem)
+        checkType(colorLegendItem, ColorLegendItem)
         self.colorLegendItem = colorLegendItem
 
 
@@ -657,7 +662,7 @@ class PgGradientEditorItemCti(ChoiceCti):
         """
         super(PgGradientEditorItemCti, self).__init__(nodeName, defaultData=defaultData,
                                                       configValues=list(GRADIENTS.keys()))
-        check_class(gradientEditorItem, pg.GradientEditorItem)
+        checkType(gradientEditorItem, pg.GradientEditorItem)
         self.gradientEditorItem = gradientEditorItem
 
 
@@ -676,7 +681,7 @@ class PgAspectRatioCti(BoolCti):
             The target axis is specified by viewBox and axisNumber (0 for x-axis, 1 for y-axis)
         """
         super(PgAspectRatioCti, self).__init__(nodeName, defaultData=defaultData, expanded=expanded)
-        check_class(viewBox, pg.ViewBox)
+        checkType(viewBox, pg.ViewBox)
 
         self.aspectRatioCti = self.insertChild(FloatCti("ratio", 1.0, minValue=0.0))
         self.viewBox = viewBox
@@ -698,7 +703,7 @@ class PgAxisFlipCti(BoolCti):
             The target axis is specified by viewBox and axisNumber (0 for x-axis, 1 for y-axis)
         """
         super(PgAxisFlipCti, self).__init__(nodeName, defaultData=defaultData)
-        check_class(viewBox, pg.ViewBox)
+        checkType(viewBox, pg.ViewBox)
         assert axisNumber in (X_AXIS, Y_AXIS), "axisNumber must be 0 or 1"
         self.viewBox = viewBox
         self.axisNumber = axisNumber
@@ -809,7 +814,7 @@ class PgGridCti(BoolGroupCti):
             The target axis is specified by viewBox and axisNumber (0 for x-axis, 1 for y-axis)
         """
         super(PgGridCti, self).__init__(nodeName, defaultData=defaultData, expanded=expanded)
-        check_class(plotItem, pg.PlotItem)
+        checkType(plotItem, pg.PlotItem)
         self.plotItem = plotItem
 
         self.xGridCti = self.insertChild(BoolCti('x-axis', defaultData))
@@ -919,7 +924,7 @@ class PgColorMapCti(AbstractCti):
 
             :param defaultData: the default index in the combobox that is used for editing
         """
-        check_class(colorLegendItem, ArgosColorLegendItem)
+        checkType(colorLegendItem, ArgosColorLegendItem)
         self.colorLegendItem = colorLegendItem
         self.cmLibModel = CmLibModelSingleton.instance()
 
