@@ -18,14 +18,6 @@ logger = logging.getLogger(__name__)
 REGEXP_FLOAT = re.compile(r'(([+-]?\d+(\.\d*)?|\.\d+)([eE][+-]?\d+)?)')
 
 
-def format_float(value): # not used
-    """Modified form of the 'g' format specifier.
-    """
-    string = "{:g}".format(value).replace("e+", "e")
-    string = re.sub("e(-?)0*(\d+)", r"e\1\2", string)
-    return string
-
-
 def valid_float_string(string):
     match = REGEXP_FLOAT.search(string)
     return match.groups()[0] == string if match else False
