@@ -1,7 +1,7 @@
 import logging
 
 from argos.external import six
-from argos.utils.cls import check_class, check_is_a_string
+from argos.utils.cls import checkType, checkIsAString
 
 logger = logging.getLogger(__name__)
 
@@ -19,7 +19,7 @@ class BaseTreeItem(object):
                 Currently we don't check for uniqueness in the children but this may change.
                 The nodeName may not contain slashes (/).
         """
-        check_class(nodeName, six.string_types, allow_none=False)
+        checkType(nodeName, six.string_types, allowNone=False)
         assert nodeName, "nodeName may not be empty"
         assert '/' not in nodeName, "nodeName may not contain slashes"
         self._nodeName = str(nodeName)
@@ -194,7 +194,7 @@ class BaseTreeItem(object):
 
         # The actual body of findByNodePath starts here
 
-        check_is_a_string(nodePath)
+        checkIsAString(nodePath)
         assert not nodePath.startswith('/'), "nodePath may not start with a slash"
 
         if not nodePath:
