@@ -4,7 +4,7 @@ import logging
 from argos.qt.treeitems import BaseTreeItem
 from argos.info import DEBUGGING
 from argos.qt import Qt, QtCore, QtSignal, QtSlot
-from argos.utils.cls import check_is_a_string, check_class
+from argos.utils.cls import checkIsAString, checkType
 from argos.widgets.constants import TREE_CELL_SIZE_HINT
 
 logger = logging.getLogger(__name__)
@@ -305,11 +305,13 @@ class BaseTreeModel(QtCore.QAbstractItemModel):
         return QtCore.QModelIndex()
 
 
-    def rootItem(self):
+    def rootItems(self):
         """ Returns an invalid index, which therefore will point to the root Item.
             Can return None if the model is empty
         """
-        return self.getItem(self.rootIndex())
+        return self.invisibleRootTreeItem.childItems
+
+
 
 
     # Originally from the editabletreemodel example but added the altItem parameter to force
@@ -454,6 +456,15 @@ class BaseTreeModel(QtCore.QAbstractItemModel):
             return self.findTopLevelItemIndex(childIndex.parent())
 
 
+    def findItemAndIndex(self, path, startIndex=None):
+        """ Searches all the model recursively (starting at startIndex) for an item where
+            item.nodePath == path.
+
+            Calls findItemAndIndexPath and returns the last item in the list.
+        """
+        return self.findItemAndIndexPath(path, startIndex=startIndex)[-1]
+
+
     def findItemAndIndexPath(self, path, startIndex=None):
         """ Searches all the model recursively (starting at startIndex) for an item where
             item.nodePath == path.
@@ -495,7 +506,7 @@ class BaseTreeModel(QtCore.QAbstractItemModel):
 
         # The actual body of findItemAndIndexPath starts here
 
-        check_is_a_string(path)
+        checkIsAString(path)
         if not path:
             raise IndexError("Item not found: {!r}".format(path))
 
@@ -508,7 +519,14 @@ class BaseTreeModel(QtCore.QAbstractItemModel):
         if not startItem:
             raise IndexError("Item not found: {!r}. No start item!".format(path))
 
-        return _auxGetByPath(path.split('/'), startItem, startIndex)
+        nodes = _auxGetByPath(path.split('/'), startItem, startIndex)
+
+        # Disabled this check. It is triggered when path doesn't start with a slash
+        # lastItem, _lastIndex = nodes[-1]
+        # if lastItem.nodePath != path:  # When can this occur? Or is it a sanity check?
+        #     raise IndexError("Path not found: {!r} (partialPath={!r})", path, lastItem.nodePath)
+
+        return nodes
 
 
     def __not_used__emitUpdateForBranch(self, parentIndex):
@@ -521,10 +539,6 @@ class BaseTreeModel(QtCore.QAbstractItemModel):
 
 
     def logItems(self, level=logging.DEBUG):
-        """ rootItem
+        """ Logs all items in the tree
         """
-        rootItem = self.rootItem()
-        if rootItem is None:
-            logger.debug("No items in: {}".format(self))
-        else:
-            rootItem.logBranch(level=level)
+        self.invisibleRootTreeItem.logBranch(level=level)
