@@ -20,10 +20,10 @@
 import logging
 
 from argos.info import DEBUGGING
-from argos.qt import QtSlot, QtCore, QtWidgets
+from argos.qt import QtSignal, QtCore, QtWidgets
 from argos.qt.togglecolumn import ToggleColumnTableWidget
 from argos.repo.baserti import BaseRti
-from argos.utils.cls import get_class_name, check_class
+from argos.utils.cls import checkType, typeName
 from argos.widgets.constants import DOCK_SPACING, DOCK_MARGIN, LEFT_DOCK_WIDTH
 from argos.widgets.display import MessageDisplay
 from argos.widgets.misc import BasePanel
@@ -42,6 +42,8 @@ class DetailBasePane(QtWidgets.QStackedWidget):
     ERROR_PAGE_IDX = 0
     CONTENTS_PAGE_IDX = 1
 
+    sigUpdated = QtSignal(bool)  # Parameter indicates sucess
+
     def __init__(self, repoTreeView, parent=None):
         """ Constructor takes a reference to the repository tree view it monitors
         """
@@ -86,17 +88,21 @@ class DetailBasePane(QtWidgets.QStackedWidget):
         """ Updates the content when the current repo tree item changes.
             The rti parameter can be None when no RTI is selected in the repository tree.
         """
-        check_class(rti, (BaseRti, int), allow_none=True)
+        checkType(rti, (BaseRti, int), allowNone=True)
         assert type(rti) != int, "rti: {}".format(rti)
         try:
             self._drawContents(rti)
             self.setCurrentIndex(self.CONTENTS_PAGE_IDX)
+            if rti is not None:
+                self.sigUpdated.emit(True)
         except Exception as ex:
             if DEBUGGING:
                 raise
             logger.exception(ex)
-            self.errorWidget.setError(msg=str(ex), title=get_class_name(ex))
+            self.errorWidget.setError(msg=str(ex), title=typeName(ex))
             self.setCurrentIndex(self.ERROR_PAGE_IDX)
+            if rti is not None:
+                self.sigUpdated.emit(False)
 
 
     def _drawContents(self, currentRti=None):
