@@ -21,8 +21,9 @@ from __future__ import print_function
 import logging, os
 
 from argos.qt import Qt, QtCore, QtGui, QtWidgets, QtSvg
-from argos.info import program_directory, DEBUGGING
-from argos.utils.cls import check_class
+from argos.info import DEBUGGING
+from argos.utils.dirs import program_directory
+from argos.utils.cls import checkType
 
 logger = logging.getLogger(__name__)
 
@@ -116,7 +117,7 @@ class RtiIconFactory(object):
                 If None, the icon will be registered for open is both True and False
             :return: QIcon
         """
-        check_class(isOpen, bool, allow_none=True)
+        checkType(isOpen, bool, allowNone=True)
 
         if fileName and not os.path.isabs(fileName):
             fileName = os.path.join(self.ICONS_DIRECTORY, fileName)
@@ -143,8 +144,8 @@ class RtiIconFactory(object):
             fileName = self._registry[(glyph, isOpen)]
         except KeyError:
             logger.warning("Unregistered icon glyph: {} (open={})".format(glyph, isOpen))
-            from argos.utils.logs import log_dictionary
-            log_dictionary(self._registry, "registry", logger=logger)
+            from argos.utils.logs import logDictionary
+            logDictionary(self._registry, "registry", logger=logger)
             raise
 
         return self.loadIcon(fileName, color=color)
