@@ -19,15 +19,16 @@
 
     The memory-RTIs store the attributes per-object (instead of returning an emtpy dictionary)
 """
-import logging, os
+import logging
+
 import numpy as np
 
 from .baserti import BaseRti, shapeToSummary, lengthToSummary
 from argos.repo.iconfactory import RtiIconFactory
-from argos.utils.cls import (check_is_a_sequence, check_is_a_mapping, check_is_an_array,
-                                is_a_sequence, is_a_mapping, is_an_array, type_name)
+from argos.utils.cls import checkIsASequence, checkIsAMapping, checkIsAnArray, \
+    isASequence, isAMapping, isAnArray, typeName
 from argos.utils.defs import DIM_TEMPLATE, SUB_DIM_TEMPLATE
-from argos.utils.misc import NOT_SPECIFIED
+from argos.utils.misc import pformat
 
 logger = logging.getLogger(__name__)
 
@@ -40,11 +41,11 @@ def _createFromObject(obj, *args, **kwargs):
         constructor (with exception of the FieldRti which is not auto-detected).
     """
     # logger.debug("_createFromObject: {} (args={}), (kwargs={})".format(obj, args, kwargs))
-    if is_a_sequence(obj):
+    if isASequence(obj):
         return SequenceRti(obj, *args, **kwargs)
-    elif is_a_mapping(obj):
+    elif isAMapping(obj):
         return MappingRti(obj, *args, **kwargs)
-    elif is_an_array(obj):
+    elif isAnArray(obj):
         return ArrayRti(obj, *args, **kwargs)
     elif isinstance(obj, bytearray):
         return ArrayRti(np.array(obj), *args, **kwargs)
@@ -130,7 +131,7 @@ class ScalarRti(BaseRti):
     def elementTypeName(self):
         """ String representation of the element type.
         """
-        return type_name(self._scalar)
+        return typeName(self._scalar)
 
 
     @property
@@ -159,8 +160,14 @@ class FieldRti(BaseRti):
             The attributes can be set so the parent's attributes can be reused.
         """
         super(FieldRti, self).__init__(nodeName, fileName=fileName, iconColor=iconColor)
-        check_is_an_array(array, allow_none=True)
-        self._array = array
+        checkIsAnArray(array, allowNone=True)
+
+        self._array = array # The array of which this field is a part
+        fieldName = self.nodeName
+
+        # dtype.fields returns a tuple with (dtype, offset, shape) so we use its first element.
+        self._fieldDtype = self._array.dtype.fields[fieldName][0]
+
         self._attributes = {} if attributes is None else attributes
 
 
@@ -173,10 +180,17 @@ class FieldRti(BaseRti):
         return self._attributes
 
 
-    def hasChildren(self):
-        """ Returns False. Field nodes never have children.
+    @property
+    def _isStructured(self):
+        """ Returns True if the variable has a structured type, otherwise returns False.
         """
-        return False
+        return bool(self._fieldDtype.names)
+
+
+    def hasChildren(self):
+        """ Returns True if the variable has a structured type, otherwise returns False.
+        """
+        return self._isStructured
 
 
     @property
@@ -209,9 +223,7 @@ class FieldRti(BaseRti):
         """ Returns the shape of the sub-array.
             An empty tuple is returned for regular fields, which have no sub array.
         """
-        fieldName = self.nodeName
-        fieldDtype = self._array.dtype.fields[fieldName][0]
-        return fieldDtype.shape
+        return self._fieldDtype.shape
 
 
     @property
@@ -236,9 +248,7 @@ class FieldRti(BaseRti):
         if self._array is None:
             return super(FieldRti, self).elementTypeName
         else:
-            fieldName = self.nodeName
-            return str(self._array.dtype.fields[fieldName][0])
-
+            return '<structured>' if self._fieldDtype.names else str(self._fieldDtype)
 
     @property
     def dimensionNames(self):
@@ -266,6 +276,24 @@ class FieldRti(BaseRti):
             return value
 
 
+    def _fetchAllChildren(self):
+        """ Fetches all fields that this variable contains.
+            Only variables with a structured data type can have fields.
+        """
+        assert self.canFetchChildren(), "canFetchChildren must be True"
+
+        childItems = []
+
+        # Add fields in case of an array of structured type.
+        if self._isStructured:
+            for fieldName in self._fieldDtype.names:
+                childItem = FieldRti(self._array[self.nodeName], nodeName=fieldName,
+                                     iconColor=self.iconColor, fileName=self.fileName)
+                childItems.append(childItem)
+
+        return childItems
+
+
     @property
     def summary(self):
         """ Returns a summary of the contents of the RTI.  E.g. 'array 20 x 30' elements.
@@ -289,7 +317,7 @@ class ArrayRti(BaseRti):
             :type array: numpy.ndarray or None
         """
         super(ArrayRti, self).__init__(nodeName=nodeName, iconColor=iconColor, fileName=fileName)
-        check_is_an_array(array, allow_none=True)
+        checkIsAnArray(array, allowNone=True)
         self._array = array
         self._attributes = {} if attributes is None else attributes
 
@@ -351,7 +379,7 @@ class ArrayRti(BaseRti):
     def dimensionality(self):
         """ String that describes if the RTI is an array, scalar, field, etc.
         """
-        return "array"
+        return "array" if self._array is not None else ""
 
 
     @property
@@ -361,8 +389,7 @@ class ArrayRti(BaseRti):
         if self._array is None:
             return super(ArrayRti, self).elementTypeName
         else:
-            dtype =  self._array.dtype
-            return '<structured>' if dtype.names else str(dtype)
+            return '<structured>' if self._isStructured else str(self._array.dtype)
 
 
     @property
@@ -439,7 +466,7 @@ class SyntheticArrayRti(ArrayRti):
         """ Evaluates the function to result an array
         """
         arr = self._fun()
-        check_is_an_array(arr)
+        checkIsAnArray(arr)
         self._array = arr
 
 
@@ -463,7 +490,7 @@ class SequenceRti(BaseRti):
             :type array: None or a Python sequence (e.g. list or tuple)
         """
         super(SequenceRti, self).__init__(nodeName=nodeName, iconColor=iconColor, fileName=fileName)
-        check_is_a_sequence(sequence, allow_none=True)
+        checkIsASequence(sequence, allowNone=True)
         self._sequence = sequence
         #self._array = NOT_SPECIFIED # To cache the sequence converted to a numpy array.
         self._attributes = {} if attributes is None else attributes
@@ -477,9 +504,16 @@ class SequenceRti(BaseRti):
         return self._attributes
 
 
+    @property
+    def dimensionality(self):
+        """ String that describes if the RTI is an array, scalar, field, etc.
+        """
+        return typeName(self._sequence)
+
+
     @property
     def typeName(self):
-        return type_name(self._sequence)
+        return typeName(self._sequence)
 
 
     @property
@@ -491,6 +525,17 @@ class SequenceRti(BaseRti):
         else:
             return lengthToSummary(len(self._sequence))
 
+    def quickLook(self, width: int):
+        """ Returns a string representation fof the RTI to use in the Quik Look pane.
+
+            We print all data, even if it is large, since it is already in memory, and it is
+            assumed to be quick.
+        """
+        if self._sequence is None:
+            return ""
+        else:
+            return pformat(self._sequence, width)
+
 
     def _fetchAllChildren(self):
         """ Adds a child item for each column
@@ -515,7 +560,7 @@ class MappingRti(BaseRti):
             The dictionary may be None for under(or None for undefined/unopened nodes)
         """
         super(MappingRti, self).__init__(nodeName=nodeName, iconColor=iconColor, fileName=fileName)
-        check_is_a_mapping(dictionary, allow_none=True)
+        checkIsAMapping(dictionary, allowNone=True)
         self._dictionary = dictionary
         self._attributes = {} if attributes is None else attributes
 
@@ -556,6 +601,17 @@ class MappingRti(BaseRti):
         # else:
         #     return lengthToSummary(len(self._dictionary))
 
+    def quickLook(self, width: int):
+        """ Returns a string representation fof the RTI to use in the Quik Look pane.
+
+            We print all data, even if it is large, since it is already in memory, and it is
+            assumed to be quick.
+        """
+        if self._dictionary is None:
+            return ""
+        else:
+            return pformat(self._dictionary, width)
+
 
     def _fetchAllChildren(self):
         """ Adds a child item for each item
@@ -565,7 +621,7 @@ class MappingRti(BaseRti):
                      .format(self, self.iconColor, self.fileName))
 
         if self.hasChildren():
-            for key, value in sorted(self._dictionary.items()):
+            for key, value in self._dictionary.items():
                 childItem = _createFromObject(value, nodeName=str(key), iconColor=self.iconColor,
                                               fileName=self.fileName)
                 childItems.append(childItem)
