@@ -24,7 +24,7 @@ from fnmatch import fnmatch
 from argos.info import DEBUGGING
 from argos.reg.basereg import BaseRegItem, BaseRegistry, RegType
 from argos.repo.iconfactory import RtiIconFactory
-from argos.utils.cls import check_class, is_a_color_str
+from argos.utils.cls import checkType, isAColorString
 
 logger = logging.getLogger(__name__)
 
@@ -38,8 +38,9 @@ ICON_COLOR_H5PY = '#00EE88'
 ICON_COLOR_NCDF4 = '#0088FF'
 ICON_COLOR_NUMPY = '#987456'
 ICON_COLOR_PANDAS = '#FB9A99'
-ICON_COLOR_PILLOW = '#880088'
+ICON_COLOR_PILLOW = '#FF40FF'
 ICON_COLOR_SCIPY = ICON_COLOR_NUMPY
+ICON_COLOR_JSON = '#880088'
 
 
 
@@ -57,8 +58,8 @@ class RtiRegItem(BaseRegItem):
         """ Constructor. See the ClassRegItem class doc string for the parameter help.
         """
         super(RtiRegItem, self).__init__(name=name, absClassName=absClassName, pythonPath=pythonPath)
-        check_class(globs, str)
-        assert is_a_color_str(iconColor), \
+        checkType(globs, str)
+        assert isAColorString(iconColor), \
             "Icon color for {} is not a color string: {!r}".format(self, iconColor)
 
         self._data['iconColor'] = iconColor
@@ -246,6 +247,11 @@ class RtiRegistry(BaseRegistry):
                        iconColor=ICON_COLOR_PILLOW,
                        globs='*.bmp;*.eps;*.im;*.gif;*.jpg;*.jpeg;*.msp;*.pcx;*.png;*.ppm;*.spi;'
                              '*.tif;*.tiff;*.xbm;*.xv'),
+
+            RtiRegItem('JSON file',
+                       'argos.repo.rtiplugins.jsonio.JsonFileRti',
+                       iconColor=ICON_COLOR_JSON,
+                       globs='*.json'),
         ]
 
 
@@ -264,7 +270,7 @@ def createGlobalRegistryFunction():
     return accessGlobalRegistry
 
 # This is actually a function definition, not a constant
-#pylint: disable=C0103
+#pylint: disable=invalid-name
 
 globalRtiRegistry = createGlobalRegistryFunction()
 globalRtiRegistry.__doc__ = "Function that returns the RtiRegistry singleton common to all windows"
