@@ -29,7 +29,7 @@ import h5py
 
 from argos.repo.iconfactory import RtiIconFactory, ICON_COLOR_UNDEF
 from argos.repo.baserti import BaseRti, shapeToSummary
-from argos.utils.cls import to_string, check_class, is_an_array
+from argos.utils.cls import toString, checkType, isAnArray
 from argos.utils.defs import DIM_TEMPLATE, SUB_DIM_TEMPLATE, CONTIGUOUS
 from argos.utils.masks import maskedEqual
 from argos.utils.moduleinfo import versionStrToTuple
@@ -137,7 +137,7 @@ def dataSetUnit(h5Dataset):
         if key in attributes:
             # In Python3 the attributes are byte strings so we must decode them
             # This a bug in h5py, see https://github.com/h5py/h5py/issues/379
-            return to_string(attributes[key])
+            return toString(attributes[key])
     # Not found
     return ''
 
@@ -178,7 +178,7 @@ def dataSetMissingValue(h5Dataset):
     for key in ('missing_value', 'MissingValue', 'missingValue', 'FillValue', '_FillValue'):
         if key in attributes:
             missingDataValue = attributes[key]
-            if is_an_array(missingDataValue) and len(missingDataValue) == 1:
+            if isAnArray(missingDataValue) and len(missingDataValue) == 1:
                 return missingDataValue[0] # In case of HDF-EOS and NetCDF files
             else:
                 return missingDataValue
@@ -216,7 +216,7 @@ class H5pyScalarRti(BaseRti):
         """
         super(H5pyScalarRti, self).__init__(
             nodeName=nodeName, fileName=fileName, iconColor=iconColor)
-        check_class(h5Dataset, h5py.Dataset)
+        checkType(h5Dataset, h5py.Dataset)
         self._h5Dataset = h5Dataset
 
 
@@ -286,7 +286,8 @@ class H5pyScalarRti(BaseRti):
     def missingDataValue(self):
         """ Returns the value to indicate missing data. None if no missing-data value is specified.
         """
-        if self._h5Dataset.size > MAX_QUICK_LOOK_SIZE:
+        # For empty datasets, self._h5Dataset.size can be None
+        if self._h5Dataset.size is not None and self._h5Dataset.size > MAX_QUICK_LOOK_SIZE:
             return "{} of {}".format(self.typeName, self.summary)
         else:
             return dataSetMissingValue(self._h5Dataset)
@@ -310,8 +311,7 @@ class H5pyScalarRti(BaseRti):
                 return self._h5Dataset[()].decode(string_info.encoding, errors="replace")
 
 
-    @property
-    def quickLook(self):
+    def quickLook(self, width: int):
         """ Returns a string representation fof the RTI to use in the Quik Look pane.
 
             Override default so bytes are decoded to strings.
@@ -325,19 +325,21 @@ class H5pyFieldRti(BaseRti):
     """
     _defaultIconGlyph = RtiIconFactory.FIELD
 
-    def __init__(self, h5Dataset, nodeName, fileName='', iconColor=ICON_COLOR_UNDEF):
+    def __init__(self, h5Dataset, nodeName, subArray, fileName='', iconColor=ICON_COLOR_UNDEF):
         """ Constructor.
-            The name of the field must be given to the nodeName parameter.
         """
         super(H5pyFieldRti, self).__init__(nodeName, fileName=fileName, iconColor=iconColor)
-        check_class(h5Dataset, h5py.Dataset)
+        checkType(h5Dataset, h5py.Dataset)
         self._h5Dataset = h5Dataset
 
+        self._subArray = subArray # The array that this field contains. Can be h5Dataset itself.
+        self._isStructured = bool(self._subArray.dtype.names)
+
 
     def hasChildren(self):
         """ Returns False. Field nodes never have children.
         """
-        return False
+        return self._isStructured
 
 
     @property
@@ -363,14 +365,7 @@ class H5pyFieldRti(BaseRti):
             If the field itself contains a sub-array it returns:
                 self.dataset[mainArrayIndex][self.nodeName][subArrayIndex]
         """
-        mainArrayNumDims = len(self._h5Dataset.shape)
-        mainIndex = index[:mainArrayNumDims]
-        mainArray = self._h5Dataset.__getitem__(mainIndex)
-        fieldArray = mainArray[self.nodeName]
-        subIndex = tuple([Ellipsis]) + index[mainArrayNumDims:]
-        slicedArray = fieldArray[subIndex]
-
-        return maskedEqual(slicedArray, self.missingDataValue)
+        return self._subArray[index]
 
 
     @property
@@ -380,25 +375,11 @@ class H5pyFieldRti(BaseRti):
         return len(self.arrayShape) # h5py datasets don't have an ndim property
 
 
-    @property
-    def _subArrayShape(self):
-        """ Returns the shape of the sub-array
-            An empty tuple is returned for regular fields, which have no sub array.
-        """
-        if self._h5Dataset.dtype.fields is None:
-            return tuple() # regular field
-        else:
-            fieldName = self.nodeName
-            fieldDtype = self._h5Dataset.dtype.fields[fieldName][0]
-            return fieldDtype.shape
-
-
     @property
     def arrayShape(self):
         """ Returns the shape of the underlying array.
-            If the field contains a subarray the shape may be longer than 1.
         """
-        return self._h5Dataset.shape + self._subArrayShape
+        return self._subArray.shape
 
 
     @property
@@ -420,23 +401,21 @@ class H5pyFieldRti(BaseRti):
     def elementTypeName(self):
         """ String representation of the element type.
         """
-        fieldName = self.nodeName
-        return dataSetType(self._h5Dataset.dtype.fields[fieldName][0], '')
+        return dataSetType(self._subArray.dtype, '')
 
 
     @property
     def typeName(self):
         """ String representation of the type. By default, the elementTypeName + dimensionality.
         """
-        fieldName = self.nodeName
-        return dataSetType(self._h5Dataset.dtype.fields[fieldName][0], self.dimensionality)
+        return dataSetType(self._subArray.dtype, self.dimensionality)
 
 
     @property
     def dimensionNames(self):
         """ Returns a list with the dimension names of the underlying HDF5 variable
         """
-        nSubDims = len(self._subArrayShape)
+        nSubDims = len(self._subArray.shape)
         subArrayDims = [SUB_DIM_TEMPLATE.format(dimNr) for dimNr in range(nSubDims)]
         return dimNamesFromDataset(self._h5Dataset) + subArrayDims
 
@@ -445,7 +424,7 @@ class H5pyFieldRti(BaseRti):
     def dimensionPaths(self):
         """ Returns a list with the full path names of the dimensions.
         """
-        nSubDims = len(self._subArrayShape)
+        nSubDims = len(self._subArray.shape)
         subArrayDims = [SUB_DIM_TEMPLATE.format(dimNr) for dimNr in range(nSubDims)]
         return dimNamesFromDataset(self._h5Dataset, useBaseName=False) + subArrayDims
 
@@ -489,22 +468,34 @@ class H5pyFieldRti(BaseRti):
         return shapeToSummary(self.arrayShape)
 
 
-    @property
-    def quickLook(self):
+    def quickLook(self, width: int):
         """ Returns a string representation fof the RTI to use in the Quik Look pane.
         """
         if self._h5Dataset.size > MAX_QUICK_LOOK_SIZE:
             return "{} of {}".format(self.typeName, self.summary)
         else:
-            fieldArray = self._h5Dataset[self.nodeName][:]
             subIndex = tuple([Ellipsis])
-            slicedArray = fieldArray[subIndex]
+            slicedArray = self._subArray[subIndex]
             data = maskedEqual(slicedArray, self.missingDataValue)
 
             string_info = h5py.check_string_dtype(self._h5Dataset.dtype)
             return _dataSetQuickLook(data, string_info)
 
 
+    def _fetchAllChildren(self):
+        """ Fetches all fields that this variable contains.
+            Only variables with a structured data type can have fields.
+        """
+        assert self.canFetchChildren(), "canFetchChildren must be True"
+
+        childItems = []
+        if self._isStructured:
+            for fieldName in self._subArray.dtype.names:
+                childItems.append(H5pyFieldRti(
+                    self._h5Dataset, fieldName, self._subArray[fieldName],
+                    fileName=self.fileName, iconColor=self.iconColor))
+        return childItems
+
 
 class H5pyDatasetRti(BaseRti):
     """ Repository Tree Item (RTI) that contains a HDF5 dataset.
@@ -517,7 +508,7 @@ class H5pyDatasetRti(BaseRti):
         """ Constructor
         """
         super(H5pyDatasetRti, self).__init__(nodeName, fileName=fileName, iconColor=iconColor)
-        check_class(h5Dataset, h5py.Dataset)
+        checkType(h5Dataset, h5py.Dataset)
         self._h5Dataset = h5Dataset
         self._isStructured = bool(self._h5Dataset.dtype.names)
 
@@ -554,7 +545,9 @@ class H5pyDatasetRti(BaseRti):
             Passes the index through to the underlying dataset.
             Converts to a masked array using the missing data value as fill_value
         """
-        return maskedEqual(self._h5Dataset.__getitem__(index), self.missingDataValue)
+        # Some old HDF5 files return bytes objects when containing string data. Convert to array.
+        array = np.array(self._h5Dataset.__getitem__(index))
+        return maskedEqual(array, self.missingDataValue)
 
 
     @property
@@ -635,8 +628,7 @@ class H5pyDatasetRti(BaseRti):
         return shapeToSummary(self.arrayShape)
 
 
-    @property
-    def quickLook(self):
+    def quickLook(self, width: int):
         """ Returns a string representation fof the RTI to use in the Quik Look pane.
         """
         if self._h5Dataset.size > MAX_QUICK_LOOK_SIZE:
@@ -647,7 +639,6 @@ class H5pyDatasetRti(BaseRti):
             return _dataSetQuickLook(data, string_info)
 
 
-
     def _fetchAllChildren(self):
         """ Fetches all fields that this variable contains.
             Only variables with a structured data type can have fields.
@@ -659,9 +650,9 @@ class H5pyDatasetRti(BaseRti):
         # Add fields
         if self._isStructured:
             for fieldName in self._h5Dataset.dtype.names:
-                childItems.append(H5pyFieldRti(self._h5Dataset, nodeName=fieldName,
-                                               fileName=self.fileName, iconColor=self.iconColor))
-
+                childItems.append(H5pyFieldRti(
+                    self._h5Dataset, nodeName=fieldName, subArray=self._h5Dataset[fieldName],
+                    fileName=self.fileName, iconColor=self.iconColor))
         return childItems
 
 
@@ -674,7 +665,7 @@ class H5pyGroupRti(BaseRti):
         """ Constructor
         """
         super(H5pyGroupRti, self).__init__(nodeName, fileName=fileName, iconColor=iconColor)
-        check_class(h5Group, h5py.Group, allow_none=True)
+        checkType(h5Group, h5py.Group, allowNone=True)
 
         self._h5Group = h5Group
 
