@@ -28,7 +28,7 @@ import math
 
 from netCDF4 import Dataset, Variable, Dimension
 
-from argos.utils.cls import check_class
+from argos.utils.cls import checkType
 from argos.repo.baserti import BaseRti, shapeToSummary
 from argos.repo.iconfactory import RtiIconFactory, ICON_COLOR_UNDEF
 from argos.utils.defs import SUB_DIM_TEMPLATE, CONTIGUOUS
@@ -100,7 +100,7 @@ class NcdfDimensionRti(BaseRti):
         """ Constructor
         """
         super(NcdfDimensionRti, self).__init__(nodeName, fileName=fileName, iconColor=iconColor)
-        check_class(ncDim, Dimension)
+        checkType(ncDim, Dimension)
 
         self._ncDim = ncDim
 
@@ -129,7 +129,7 @@ class NcdfFieldRti(BaseRti):
             The name of the field must be given to the nodeName parameter.
         """
         super(NcdfFieldRti, self).__init__(nodeName, fileName=fileName, iconColor=iconColor)
-        check_class(ncVar, Variable)
+        checkType(ncVar, Variable)
 
         self._ncVar = ncVar
 
@@ -273,8 +273,7 @@ class NcdfFieldRti(BaseRti):
         return shapeToSummary(self.arrayShape)
 
 
-    @property
-    def quickLook(self):
+    def quickLook(self, width: int):
         """ Returns a string representation fof the RTI to use in the Quik Look pane.
         """
         if math.prod(self._ncVar.shape) > MAX_QUICK_LOOK_SIZE:
@@ -297,7 +296,7 @@ class NcdfVariableRti(BaseRti):
         """ Constructor
         """
         super(NcdfVariableRti, self).__init__(nodeName, fileName=fileName, iconColor=iconColor)
-        check_class(ncVar, Variable)
+        checkType(ncVar, Variable)
         self._ncVar = ncVar
 
         try:
@@ -429,8 +428,7 @@ class NcdfVariableRti(BaseRti):
             return shapeToSummary(self.arrayShape)
 
 
-    @property
-    def quickLook(self):
+    def quickLook(self, width: int):
         """ Returns a string representation fof the RTI to use in the Quik Look pane.
         """
         # In python 3.8 we can use math.prod(self._ncVar.shape)
@@ -441,7 +439,7 @@ class NcdfVariableRti(BaseRti):
         if  product > MAX_QUICK_LOOK_SIZE:
             return "{} of {}".format(self.typeName, self.summary)
         else:
-            return super(NcdfVariableRti, self).quickLook
+            return super(NcdfVariableRti, self).quickLook(width)
 
 
     def _fetchAllChildren(self):
@@ -471,7 +469,7 @@ class NcdfGroupRti(BaseRti):
         """ Constructor
         """
         super(NcdfGroupRti, self).__init__(nodeName, fileName=fileName, iconColor=iconColor)
-        check_class(ncGroup, Dataset, allow_none=True)
+        checkType(ncGroup, Dataset, allowNone=True)
 
         self._ncGroup = ncGroup
 
