@@ -1,16 +1,24 @@
-"""
-    'About' dialog window that shows version information.
-
-"""
-from __future__ import absolute_import
-from __future__ import print_function
-from __future__ import division
+# -*- coding: utf-8 -*-
+# This file is part of Argos.
+#
+# Argos is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# Argos is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with Argos. If not, see <http://www.gnu.org/licenses/>.
 
 import logging
 
 from argos.info import PROJECT_NAME, VERSION, DEBUGGING
 from argos.qt import QtCore, QtGui, QtWidgets
-from argos.utils.cls import is_a_string
+from argos.utils.cls import isAString
 from argos.utils import moduleinfo as mi
 from argos.widgets.constants import MONO_FONT, FONT_SIZE
 
@@ -19,7 +27,7 @@ logger = logging.getLogger(__name__)
 
 # The main window inherits from a Qt class, therefore it has many
 # ancestors public methods and attributes.
-# pylint: disable=R0901, R0902, R0904, W0201
+# pylint: disable=too-many-ancestors, too-many-instance-attributes, too-many-public-methods, attribute-defined-outside-init
 
 
 class AboutDialog(QtWidgets.QDialog):
@@ -68,7 +76,7 @@ class AboutDialog(QtWidgets.QDialog):
             :param moduleInfo: can either be a string or a module info class.
                 In the first case, an object is instantiated as ImportedModuleInfo(moduleInfo).
         """
-        if is_a_string(moduleInfo):
+        if isAString(moduleInfo):
             moduleInfo = mi.ImportedModuleInfo(moduleInfo)
 
         line = "{:15s}: {}".format(moduleInfo.name, moduleInfo.verboseVersion)
