@@ -49,14 +49,14 @@ import logging
 from argos.qt import QtCore, QtWidgets
 from argos.qt.togglecolumn import ToggleColumnTreeView
 from argos.qt.treemodels import BaseTreeModel
-from argos.utils.cls import check_class
+from argos.utils.cls import checkType
 from argos.widgets.constants import TREE_ICON_SIZE
 
 
 logger = logging.getLogger(__name__)
 
 # Qt classes have many ancestors
-#pylint: disable=R0901
+#pylint: disable=too-many-ancestors
 
 class ArgosTreeView(ToggleColumnTreeView):
     """ QTreeView that defines common functionality, look and feel for all tree views in Argos.
@@ -93,7 +93,7 @@ class ArgosTreeView(ToggleColumnTreeView):
         """ Sets the model.
             Checks that the model is a
         """
-        check_class(model, BaseTreeModel)
+        checkType(model, BaseTreeModel)
         super(ArgosTreeView, self).setModel(model)
 
 
