@@ -20,6 +20,9 @@
 import sys
 from argos.qt import QtCore, QtGui, QtWidgets
 
+# Use large numpy line length in the Quicklook panel
+NUMPY_LINE_WIDTH = sys.maxsize
+
 #TREE_ROW_HEIGHT = 20 # pixels
 TREE_CELL_SIZE_HINT = QtCore.QSize(100, 20)
 TREE_ICON_SIZE = QtCore.QSize(16, 16)
@@ -28,20 +31,21 @@ TREE_ICON_SIZE = QtCore.QSize(16, 16)
 COLLECTOR_TREE_ICON_SIZE = QtCore.QSize(20, 20)
 
 # Initial dock widths of the main window
-LEFT_DOCK_WIDTH = 360
+LEFT_DOCK_WIDTH = 440  # needs room for scroll bars
 RIGHT_DOCK_WIDTH = 320
 TOP_DOCK_HEIGHT = 75
 
-COL_NODE_NAME_WIDTH = 200
-COL_SHAPE_WIDTH = 90
-COL_ELEM_TYPE_WIDTH = 50
+COL_NODE_NAME_WIDTH = 180
+COL_KIND_WIDTH = 50
+COL_ELEM_TYPE_WIDTH = 80
+COL_SUMMARY_WIDTH = 110 # will be stretched
 
 
 # Spacing and margin in central widgets in pixels
 CENTRAL_SPACING = 0
 CENTRAL_MARGIN  = 0
 
-# Spacing and margin in dock widgets in pixels. Is now set in style sheet padding.
+# Spacing and margin in dock widgets in pixels. Is now set in style sheet margin.
 
 DOCK_SPACING = 0
 DOCK_MARGIN  = 0
