@@ -20,13 +20,12 @@
 
 """
 
-from __future__ import absolute_import, division, print_function
 
 import base64
 import cProfile
+import logging
 import os.path
 import pstats
-import time
 from functools import partial
 
 import numpy as np
@@ -35,7 +34,7 @@ from argos.collect.collector import Collector
 from argos.config.abstractcti import AbstractCti
 from argos.config.configtreemodel import ConfigTreeModel
 from argos.config.configtreeview import ConfigWidget
-from argos.info import DEBUGGING, TESTING, PROJECT_NAME, PROFILING, EXIT_CODE_RESTART
+from argos.info import DEBUGGING, PROJECT_NAME, PROFILING, EXIT_CODE_RESTART
 from argos.inspector.abstract import AbstractInspector, UpdateReason
 from argos.inspector.errormsg import ErrorMsgInspector
 from argos.inspector.selectionpane import InspectorSelectionPane
@@ -47,23 +46,18 @@ from argos.repo.iconfactory import RtiIconFactory
 from argos.repo.registry import RtiRegistry
 from argos.repo.repotreeview import RepoWidget
 from argos.repo.testdata import createArgosTestData
-from argos.utils.cls import check_class, check_is_a_sequence
+from argos.utils.cls import checkType, checkIsASequence
 from argos.utils.dirs import argosConfigDirectory, argosLogDirectory
-from argos.utils.misc import string_to_identifier
+from argos.utils.misc import stringToIdentifier
 from argos.utils.moduleinfo import versionStrToTuple
 from argos.widgets.aboutdialog import AboutDialog
-from argos.widgets.constants import CENTRAL_MARGIN, CENTRAL_SPACING
-from argos.widgets.misc import processEvents
-
-
-import logging
-
+from argos.widgets.testwalkdialog import TestWalkDialog
 
 logger = logging.getLogger(__name__)
 
 # The main window inherits from a Qt class, therefore it has many
 # ancestors public methods and attributes.
-# pylint: disable=R0901, R0902, R0904, W0201
+# pylint: disable=too-many-ancestors, too-many-instance-attributes, too-many-public-methods, attribute-defined-outside-init
 
 
 class MainWindow(QtWidgets.QMainWindow):
@@ -83,7 +77,6 @@ class MainWindow(QtWidgets.QMainWindow):
         self._windowNumber = MainWindow.__numInstances # Used only for debugging
         MainWindow.__numInstances += 1
 
-        self.__nodesVisited = 0 # during testing
         if PROFILING:
             # Profiler that measures the drawing of the inspectors.
             self._profFileName = "inspectors.prof"
@@ -91,15 +84,20 @@ class MainWindow(QtWidgets.QMainWindow):
             logger.warning("Profiling is on for {}. This may cost a bit of CPU time.")
             self._profiler = cProfile.Profile()
 
+        self.testWalkDialog = TestWalkDialog(mainWindow=self, parent=self)  # don't show yet
+
         self._collector = None
         self._inspector = ErrorMsgInspector(
             self._collector, "No inspector yet. Please select one from the menu.")
         self._inspector.sigShowMessage.connect(self.sigShowMessage)
+        self._inspector.sigUpdated.connect(self.testWalkDialog.setTestResult)
         self._inspectorRegItem = None # The registered inspector item a InspectorRegItem)
 
         self._argosApplication = argosApplication
         self._configTreeModel = ConfigTreeModel()
         self._inspectorStates = {}  # keeps track of earlier inspector states
+        self._currentTestName = None
+        self._failedTests = []
 
         self.setDockNestingEnabled(False)
         self.setCorner(Qt.TopLeftCorner, Qt.LeftDockWidgetArea)
@@ -117,10 +115,14 @@ class MainWindow(QtWidgets.QMainWindow):
         center = desktopRect.center()
         self.move(round(center.x() - self.width () * 0.5), round(center.y() - self.height() * 0.5))
 
+        self.__setupActions()
         self.__setupMenus()
         self.__setupViews()
         self.__setupDockWidgets()
 
+        for detailsPane in self.repoWidget.detailDockPanes:
+            detailsPane.sigUpdated.connect(self.testWalkDialog.setTestResult)
+
 
     def finalize(self):
         """ Is called before destruction (when closing).
@@ -128,6 +130,8 @@ class MainWindow(QtWidgets.QMainWindow):
         """
         logger.debug("Finalizing: {}".format(self))
 
+        self.testWalkDialog.finalize()
+
         # Disconnect signals
         self.collector.sigContentsChanged.disconnect(self.collectorContentsChanged)
         self._configTreeModel.sigItemChanged.disconnect(self.configContentsChanged)
@@ -135,6 +139,10 @@ class MainWindow(QtWidgets.QMainWindow):
         self.sigShowMessage.disconnect(self.inspectorSelectionPane.showMessage)
         self._collector.sigShowMessage.disconnect(self.sigShowMessage)
         self._inspector.sigShowMessage.disconnect(self.sigShowMessage)
+        self._inspector.sigUpdated.disconnect(self.testWalkDialog.setTestResult)
+
+        for detailsPane in self.repoWidget.detailDockPanes:
+            detailsPane.sigUpdated.disconnect(self.testWalkDialog.setTestResult)
 
         if PROFILING:
             logger.info("Saving profiling information to {}"
@@ -213,6 +221,41 @@ class MainWindow(QtWidgets.QMainWindow):
             subMenu.addAction(action)
 
 
+    def __setupActions(self):
+        """ Creates actions that are always usable, even if they are not added to the main menu.
+
+            Some actions are only added to the menu in debugging mode.
+        """
+        self.showTestWalkDialogAction = QtWidgets.QAction("Test Walk...", self)
+        self.showTestWalkDialogAction.setToolTip("Shows test-walk dialog windows.")
+        self.showTestWalkDialogAction.setShortcut("Ctrl+T")
+        self.showTestWalkDialogAction.triggered.connect(self.showTestWalkDialog)
+        self.addAction(self.showTestWalkDialogAction)
+
+        # The action added to the menu in the repopulateWindowMenu method, which is called by
+        # the ArgosApplication object every time a window is added or removed.
+        self.activateWindowAction = QtWidgets.QAction("Window #{}".format(self.windowNumber), self)
+        self.activateWindowAction.triggered.connect(self.activateAndRaise)
+        self.activateWindowAction.setCheckable(True)
+        #self.addAction(self.activateWindowAction)
+
+        if self.windowNumber <= 9:
+            self.activateWindowAction.setShortcut(QtGui.QKeySequence(
+                "Alt+{}".format(self.windowNumber)))
+
+        self.addTestDataAction = QtWidgets.QAction("Add Test Data", self)
+        self.addTestDataAction.setToolTip("Add in-memory test data to the tree.")
+        self.addTestDataAction.setShortcut("Meta+A")
+        self.addTestDataAction.triggered.connect(self.addTestData)
+        self.addAction(self.addTestDataAction)
+
+        self.myTestAction = QtWidgets.QAction("My Test", self)
+        self.myTestAction.setToolTip("Ad-hoc test procedure for debugging.")
+        self.myTestAction.setShortcut("Meta+T")
+        self.myTestAction.triggered.connect(self.myTest)
+        self.addAction(self.myTestAction)
+
+
     def __setupMenus(self):
         """ Sets up the main menu.
         """
@@ -265,19 +308,20 @@ class MainWindow(QtWidgets.QMainWindow):
         self.panelsMenu = self.viewMenu.addMenu("&Panels")
         self.tableHeadersMenu = self.viewMenu.addMenu("&Table Headers")
 
+        self.viewMenu.addSeparator()
+        self.viewMenu.addAction(self.showTestWalkDialogAction)
+
         ### Config Menu ###
+
         self.configMenu = menuBar.addMenu("Configure")
 
         app = self.argosApplication
         action = self.configMenu.addAction("&File Format Plugins...",
             lambda: self.execPluginsDialog("File Formats", app.rtiRegistry))
-        if DEBUGGING:
-            action.setShortcut(QtGui.QKeySequence("Ctrl+P"))
+        action.setShortcut(QtGui.QKeySequence("Ctrl+P"))
 
         action = self.configMenu.addAction("&Inspector Plugins...",
             lambda: self.execPluginsDialog("Inspectors", app.inspectorRegistry))
-        # if DEBUGGING:
-        #     action.setShortcut(QtGui.QKeySequence("Ctrl+P"))
 
         self.configMenu.addSeparator()
 
@@ -286,16 +330,9 @@ class MainWindow(QtWidgets.QMainWindow):
             lambda: self.openInExternalApp(argosConfigDirectory()))
 
         ### Window Menu ###
-        self.windowMenu = menuBar.addMenu("&Window")
 
-        # The action added to the menu in the repopulateWindowMenu method, which is called by
-        # the ArgosApplication object every time a window is added or removed.
-        self.activateWindowAction = QtWidgets.QAction(
-            "Window #{}".format(self.windowNumber), self,
-            triggered=self.activateAndRaise, checkable=True)
-        if self.windowNumber <= 9:
-            self.activateWindowAction.setShortcut(QtGui.QKeySequence(
-                "Alt+{}".format(self.windowNumber)))
+        # Will be populated in repopulateWindowMenu
+        self.windowMenu = menuBar.addMenu("&Window")
 
         ### Help Menu ###
         menuBar.addSeparator()
@@ -312,12 +349,20 @@ class MainWindow(QtWidgets.QMainWindow):
 
         helpMenu.addAction('&About...', self.about)
 
-        if TESTING or DEBUGGING:
+        if DEBUGGING:
+
             helpMenu.addSeparator()
-            helpMenu.addAction("&My Test", self.myTest, "Meta+T")
-            helpMenu.addAction("&Test Walk Current", self.testWalkCurrentNode, "Meta+W")
-            helpMenu.addAction("&Extensive Test Walk", self.testWalk, "Meta+E")
-            helpMenu.addAction("Add Test Data", self.addTestData, "Meta+A")
+            helpMenu.addAction(self.addTestDataAction)
+
+            helpMenu.addAction(
+                "Quick Walk &Current Node",
+                lambda: self.testWalkDialog.walkCurrentRepoNode(False, False), "Meta+Q")
+            helpMenu.addAction(
+                "Walk &All Nodes",
+                lambda: self.testWalkDialog.walkAllRepoNodes(True, True), "Meta+W")  # meta works on MacOs
+
+            helpMenu.addSeparator()
+            helpMenu.addAction(self.myTestAction)
 
 
 
@@ -516,7 +561,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
         dockWidget = QtWidgets.QDockWidget(title, parent=self)
         # Use dock2 as name to reset at upgrade
-        dockWidget.setObjectName("dock2_" + string_to_identifier(title)) # Use doc
+        dockWidget.setObjectName("dock2_" + stringToIdentifier(title)) # Use doc
         dockWidget.setWidget(widget)
         self.addDockWidget(area, dockWidget)
 
@@ -583,7 +628,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
             Emits the sigInspectorChanged(self.inspectorRegItem)
         """
-        logger.info("Setting inspector: {}".format(identifier))
+        logger.debug("Setting inspector: {}".format(identifier))
 
         # Use the identifier to find a registered inspector and set self.inspectorRegItem.
         # Then create an inspector object from it.
@@ -617,7 +662,7 @@ class MainWindow(QtWidgets.QMainWindow):
 
         ###### Set self.inspector ######
 
-        check_class(inspector, AbstractInspector, allow_none=True)
+        checkType(inspector, AbstractInspector, allowNone=True)
 
         logger.debug("Disabling updates.")
         self.setUpdatesEnabled(False)
@@ -626,6 +671,7 @@ class MainWindow(QtWidgets.QMainWindow):
             self._storeInspectorState(oldInspectorRegItem, oldInspector)
 
             oldInspector.sigShowMessage.disconnect(self.sigShowMessage)
+            oldInspector.sigUpdated.disconnect(self.testWalkDialog.setTestResult)
             oldInspector.finalize()
             self.wrapperLayout.removeWidget(oldInspector)
             oldInspector.deleteLater()
@@ -650,6 +696,7 @@ class MainWindow(QtWidgets.QMainWindow):
                     self.collector.clearAndSetComboBoxes(self.inspector.axesNames())
 
                 self._inspector.sigShowMessage.connect(self.sigShowMessage)
+                self._inspector.sigUpdated.connect(self.testWalkDialog.setTestResult)
                 self.wrapperLayout.addWidget(self.inspector)
             finally:
                 self.collector.blockSignals(oldBlockState)
@@ -755,7 +802,7 @@ class MainWindow(QtWidgets.QMainWindow):
             :param fileMode: is passed to the file dialog.
             :rtype fileMode: QtWidgets.QFileDialog.FileMode constant
         """
-        check_is_a_sequence(fileNames, allow_none=True)
+        checkIsASequence(fileNames, allowNone=True)
         if fileNames is None:
             dialog = QtWidgets.QFileDialog(self, caption=caption)
 
@@ -805,8 +852,6 @@ class MainWindow(QtWidgets.QMainWindow):
         """
         lastItem, lastIndex = self.repoWidget.repoTreeView.expandPath(path)
         self.repoWidget.repoTreeView.setCurrentIndex(lastIndex)
-        if lastItem.nodePath != path:
-            raise IndexError("Path not found: {!r} (partialPath={!r})", path, lastItem.nodePath)
         return lastItem, lastIndex
 
 
@@ -824,8 +869,8 @@ class MainWindow(QtWidgets.QMainWindow):
             return lastItem, lastIndex
         except Exception as ex:
             logger.warning("Unable to select {!r} because: {}".format(path, ex))
-            # if DEBUGGING:
-            #     raise
+            if DEBUGGING:
+                raise
             return None, None
 
 
@@ -868,18 +913,22 @@ class MainWindow(QtWidgets.QMainWindow):
         """
         self._storeInspectorState(self.inspectorRegItem, self.inspector)
 
+        twLayoutCfg, twCfg = self.testWalkDialog.marshall()
+
         layoutCfg = dict(
             repoWidget = self.repoWidget.marshall(),
             configTreeHeaders =  self.configWidget.configTreeView.marshall(),
             collectorHeaders = self.collector.tree.marshall(),
             winGeom = base64.b64encode(getWidgetGeom(self)).decode('ascii'),
-            winState = base64.b64encode(getWidgetState(self)).decode('ascii')
+            winState = base64.b64encode(getWidgetState(self)).decode('ascii'),
+            testWalkDialog = twLayoutCfg,
         )
 
         cfg = dict(
             configWidget = self.configWidget.marshall(),
             curInspector = self.inspectorRegItem.identifier if self.inspectorRegItem else '',
             inspectors = self._inspectorStates,
+            testWalkDialog = twCfg,
             layout = layoutCfg,
         )
         return cfg
@@ -906,6 +955,9 @@ class MainWindow(QtWidgets.QMainWindow):
         self.configWidget.configTreeView.unmarshall(layoutCfg.get('configTreeHeaders', ''))
         self.collector.tree.unmarshall(layoutCfg.get('collectorHeaders', ''))
 
+        self.testWalkDialog.unmarshall(layoutCfg.get('testWalkDialog', {}),
+                                       cfg.get('testWalkDialog', {}))
+
         if 'winGeom' in layoutCfg:
             self.restoreGeometry(base64.b64decode(layoutCfg['winGeom']))
         if 'winState' in layoutCfg:
@@ -979,7 +1031,6 @@ class MainWindow(QtWidgets.QMainWindow):
         aboutDialog.addDependencyInfo()
 
 
-    @QtSlot()
     def addTestData(self):
         """ Adds test data to the repository
         """
@@ -987,159 +1038,19 @@ class MainWindow(QtWidgets.QMainWindow):
         self.argosApplication.repo.insertItem(createArgosTestData())
 
 
+    def showTestWalkDialog(self):
+        """ Shows the test-walk dialog box
+        """
+        self.testWalkDialog.show()
+        self.testWalkDialog.raise_()
+
+
     @QtSlot()
     def myTest(self):
-        """ Function for small ad-hoc tests
+        """ Function for small ad-hoc tests that can be called from the menu.
         """
         logger.info("--------- myTest function called --------------------")
 
-        repoTreeView = self.repoWidget.repoTreeView
-        curItem, curIdx = repoTreeView.getCurrentItem()
-
-        #repoTreeView.closeItem(self.getRowCurrentIndex())
-        repoTreeView.collapse(curIdx)
-        repoTreeView.closeItem(curIdx)
-
-        #self.repoWidget.repoTreeView.closeCurrentItem2()
+        logger.info("--------- myTest function done --------------------")
 
 
-    def testWalkCurrentNode(self):
-        """ Will visit all nodes below the currently selected node
-        """
-        curItem, _curIdx = self.repoWidget.repoTreeView.getCurrentItem()
-        logger.info("CurrentItem: {}".format(curItem.nodePath))
-        self.testWalk(rootNodes=[curItem.nodePath])
-
-
-    def testWalk(self, rootNodes=None):
-        """ Will visit a list of (hard coded) preselected nodes.
-        """
-        if rootNodes is None:
-
-            # Subtrees that will be visited. At the moment only data on my development PC.
-            #rootNodes = ['/argos/icm/S5P_ICM_CA_UVN_20120919T051721_20120919T065655_01890_01_001000_20151002T140000.h5']
-            #rootNodes = ['/argos/martin', '/argos/images', '/argos/mini_scanner_output', '/myDict']
-            rootNodes = ['/argos/exdir', '/argos/martin', '/argos/images', '/argos/ucar', '/myDict']
-            #rootNodes = ['/myDict']
-            #rootNodes = ['/argos/mini_scanner_output']  # TODO
-
-            #/argos/trop/S5P_NRTI_L2__AER_LH_20150821T201929_20150821T202429_45862_01_000000_20170506T003521.nc/PRODUCT/dim_surface_albedo
-            #/argos/trop/2015_03_16T16_32_16_MonA/after_dccorr_l1bavg/trl1brb8g.lx.nc/BAND8/ICID_30683_GROUP_00001/OBSERVATIONS/measurement_flags
-            #/argos/trop/2015_03_16T16_32_16_MonA/after_dccorr_l1bavg/trl1brb8g.lx.nc/BAND8/ICID_30683_GROUP_00001/INSTRUMENT/instrument_configuration
-
-            #rootNodes = ['/argos/trop/2015_03_16T16_32_16_MonA/after_dccorr_l1bavg/trl1brb8g.lx.nc/BAND8/ICID_30683_GROUP_00001']
-
-            # Skip nodes that give known, unfixable errors, or that take a long time to load.
-
-            skipLong = [ # Skip nodes that that take a long time to load.
-                '/argos/images/peter_karpov',
-                '/argos/images/eclipseclouds_tamo_2017_geo.tif',
-            ]
-            skipError = [
-                #'/myDict/numbers/-inf', '/myDict/numbers/nan', '/myDict/age', '/myDict/numbers/int', # These seem to work now
-                #'/myDict/numbers/large float', # These give errors in 2D image plot
-                '/myDict/structured_arr4', # gives ValueError: Unable to transform (63, 63) to dtype [('r', '|u1'), ('', '|V1'), ('b', '|u1')]
-                '/argos/trop/2015_01_07T09_29_12_svn4465_wls_prnu/ql_test_020_minutes-020-021/engDat.nc/SATELLITE_INFO/processing_events',
-                '/argos/mini_scanner_output/multiple_dimension_scales.h5', # TODO:
-                '/argos/images/eclipseclouds_tamo_2017_geo.tif', # Fails in Python 3.10. Perhaps will work later.
-            ]
-
-            # Don't import plugins at module level.
-            from argos.inspector.qtplugins.text import TextInspector
-            from argos.inspector.pgplugins.imageplot2d import PgImagePlot2d
-
-            if isinstance(self._inspector, TextInspector):
-                 # TODO: let's fix the Pandas errors when users can open a Pandas in memory.
-                skipError.append('/myDict/pandas/simple series/index')  # AttributeError: 'str' object has no attribute 'ndim'
-                skipError.append('/myDict/pandas/df/index')  # Gives AssertionError: <class 'numpy.int64'>
-                skipError.append('/myDict/pandas/df/columns')  # Gives TAttributeError: 'str' object has no attribute 'ndim'
-                skipError.append('/myDict/pandas/multi-index/index')  # Gives TypeError: len() of unsized object. Unclear whe. # TODO
-                skipError.append('/myDict/structured_masked_arr2')    # Fails with ma.copy: 'numpy.void' object has no attribute '_update_from'
-                skipError.append('/myDict/pandas/panel/major_axis')   # ValueError: object __array__ method not producing an array
-                skipError.append('/argos/gstp-rad/2014-04-29_FEL-350/2014-04-29T11_53_38Nothing m2.h5/radiometer_configuration/wheel_configuration') # AttributeError: 'bytes' object has no attribute 'dtype'
-
-            elif isinstance(self._inspector, PgImagePlot2d) or isinstance(self._inspector, PgImagePlot2d):
-                if versionStrToTuple(np.__version__) < (1,19,0):
-                    # Fails with ma.copy: 'numpy.void' object has no attribute '_update_from'
-                    skipError.append('/argos/ucar/madis-hydro.nc/firstOverflow'),
-
-
-            skipPaths = skipLong + skipError
-        else:
-            skipPaths = []
-
-        # Add myDict if not yet present
-        nodeItem, nodeIndex = self.trySelectRtiByPath('/myDict')
-        if nodeItem is None:
-            self.addTestData()
-
-        self.__nodesVisited = 0
-
-        def visitNodes(index):
-            """ Visits all the nodes recursively.
-            """
-            assert index.isValid(), "sanity check"
-            self.__nodesVisited += 1
-
-            repoModel = self.repoWidget.repoTreeView.model()
-            item = repoModel.getItem(index)
-            logger.info("Visiting: {!r} ({} children)".
-                        format(item.nodePath, repoModel.rowCount(index)))
-
-            # Select index
-            if item.nodePath in skipPaths:
-                logger.warning("Skipping node during testing: {}".format(item.nodePath))
-                return
-            else:
-                logger.debug("Not skipping node during testing: {}".format(item.nodePath))
-
-            self.repoWidget.repoTreeView.setCurrentIndex(index)
-            self.repoWidget.repoTreeView.setExpanded(index, True)
-
-            # Try properties, attributes and quicklook tabs
-            for idx in range(self.repoWidget.tabWidget.count()):
-                # if idx != 2:
-                #     continue
-                logger.debug("Setting repo tab index to: {}".format(idx))
-                self.repoWidget.tabWidget.setCurrentIndex(idx)
-                processEvents() # Cause Qt to update UI
-
-            for rowNr in range(repoModel.rowCount(index)):
-                childIndex = repoModel.index(rowNr, 0, parentIndex=index)
-                visitNodes(childIndex)
-
-
-        # Actual body
-        logger.info("-------------- Running Tests ----------------")
-        try:
-            timeAtStart = time.perf_counter()
-        except AttributeError:
-            timeAtStart = 0.0 # Python 2.7
-
-        logger.info("Visiting all nodes below: {}".format(rootNodes))
-        check_is_a_sequence(rootNodes) # prevent accidental iteration over strings.
-
-        prevRootNode = None
-
-        for rootNode in rootNodes:
-            logger.debug("Testing root node: {!r}".format(rootNode))
-
-            nodeItem, nodeIndex = self.selectRtiByPath(rootNode)
-            assert nodeItem is not None, "Test data not found, rootNode: {}".format(rootNode)
-            assert nodeIndex
-
-            if prevRootNode is not None:
-                logger.debug("Closing: {}".format(prevRootNode.nodePath))
-                prevRootNode.close()
-
-            visitNodes(nodeIndex)
-
-        try:
-            timeAtEnd = time.perf_counter()
-        except AttributeError:
-            timeAtEnd = 1.0 # Python 2.7
-
-        duration = timeAtEnd - timeAtStart
-        logger.info("Visited {} nodes in {:.1f} seconds ({:.1f} nodes/second)"
-                    .format(self.__nodesVisited, duration, self.__nodesVisited/duration))
-        logger.info("-------------- Tests Done ----------------")
